@@ -10,7 +10,7 @@ class BackendPluginFactory(object):
         ie : mybackend = BackendPluginFactory.create()
     """
     @classmethod
-    def create(self, plugin_name="mongodb", **kwargs):
+    def create(cls, plugin_name="mongodb", **kwargs):
         """Import the needed lib and return an object NmapBackendPlugin
            representing the backend of your desire.
            NmapBackendPlugin is an abstract class, to know what argument
@@ -25,5 +25,8 @@ class BackendPluginFactory(object):
         pluginclasses = inspect.getmembers(pluginobj, inspect.isclass)
         for classname, classobj in pluginclasses:
             if inspect.getmodule(classobj).__name__.find(plugin_path) == 0:
-                backendplugin = classobj(**kwargs)
+                try:
+                    backendplugin = classobj(**kwargs)
+                except Exception as error:
+                    print "Cannot create Backend: %s" % (error)
         return backendplugin
